package com.huiju.welcome.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.SysRole;
import com.huiju.welcome.model.SysRoleMenu;
import com.huiju.welcome.service.ISysRoleMenuService;
import com.huiju.welcome.service.ISysRoleService;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 角色控制器
 * @author weiximei
 */
@RestController
@RequestMapping("/")
@Api(value = "角色控制器", description = "角色控制器")
public class SysRoleController {

    @Autowired
    private ISysRoleService iSysRoleService;

    @Autowired
    private ISysRoleMenuService iSysRoleMenuService;

    @ApiOperation("查询角色列表")
    @GetMapping(value = "/role")
    public ResponseBean getList(@RequestParam(value = "roleName", required = false) String roleName,
                                @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return iSysRoleService.getList(roleName, pageNum, pageSize);
    }

    @ApiOperation("根据角色Id查询")
    @GetMapping("/role/{id}")
    public ResponseBean getRoleId(@PathVariable("id") Integer roleId) {
        return iSysRoleService.getByRoleId(roleId);
    }

    @ApiOperation("添加角色")
    @PostMapping("/role")
    public ResponseBean roleSave(@RequestParam("roleName") String roleName, @RequestParam("menuIds") String [] menuIds) {
        SysRole sysRole = new SysRole();
        sysRole.setRoleName(roleName);
        return iSysRoleService.roleSaveOrUpdate(sysRole, menuIds);
    }

    @ApiOperation("修改角色")
    @PutMapping("/role")
    public ResponseBean roleUpdate(@RequestParam("roleId") Integer roleId,
                                   @RequestParam("roleName") String roleName,
                                   @RequestParam("menuIds") String [] menuIds){
        SysRole sysRole = new SysRole();
        sysRole.setRoleId(roleId);
        sysRole.setRoleName(roleName);
        return iSysRoleService.roleSaveOrUpdate(sysRole, menuIds);
    }

    @ApiOperation("查询所有菜单")
    @GetMapping("/menus")
    public ResponseBean getMenus() {
        return iSysRoleService.getMenus();
    }


    @ApiOperation("删除角色")
    @DeleteMapping("/role/{id}")
    public ResponseBean deleteRole(@PathVariable("id") Integer roleId){
        // 删除角色
        SysRole sysRole = iSysRoleService.getById(roleId);
        sysRole.setStatus(StatusUtils.Delete);
        iSysRoleService.updateById(sysRole);

        // 删除角色对应菜单
        QueryWrapper<SysRoleMenu> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("role_id", roleId);
        iSysRoleMenuService.remove(queryWrapper);

        return ResponseBean.success("ok");
    }
}
